@@ -1,3 +1,11 @@
+# ruff: noqa: E402 .. filterwarnings messes with import order
+
+import warnings
+
+warnings.filterwarnings(
+    "ignore", message="pkg_resources is deprecated as an API"
+)  # fake_useragent
+
 import pytest
 from mongomock_motor import AsyncMongoMockClient
 
